package cc.niushuai.projects.demo.aspectlock.common.anno;

import java.lang.annotation.*;

/**
 * AopLock 注解
 *
 * @author niushuai
 * @date 2021/12/22 10:01
 */
@Target(value = ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
@Inherited
@Documented
public @interface AopLock {

    /**
     * 是否启用 默认false
     * <pre>
     *  true 表示要利用反射来获取对象属性值作为key和value
     *  false 表示直接将key作为key, value作为value
     * </pre>
     */
    boolean enableReflect() default false;

    /**
     * key 多个数据会组合到一起
     * <pre>
     * 若为基本类型或其包装类型 直接 paramName 即可
     * 若为对象请用 paramName.fieldName 的形式
     * <pre/>
     */
    String[] key();

    /**
     * value 多个数据会组合到一起
     */
    String[] value() default "aopLock_default_value";

    /**
     * key前缀
     */
    String prefix() default "";

    /**
     * key 数组element分隔符
     */
    String keySeparator() default "";

    /**
     * value 数组element分隔符
     */
    String valueSeparator() default "";

    /**
     * 有效期 默认3000ms
     */
    long period() default 3000L;
}
